pub enum CacheableResource<T> {
NotModified,
New {
entity_tag: EntityTag,
data: T,
},
}Expand description
Represents a resource that can be cached, along with its EntityTag.
This enum is used to provide cacheable data to the consumers of the credential provider. It allows a data provider to return either new data (with an EntityTag) or indicate that the caller’s cached version (identified by a previously provided EntityTag) is still valid.
Variants
NotModified
Indicates that the resource has not been modified and the cached version is still valid.
New
Contains the new resource data and its associated EntityTag.