pub struct CredentialsError { /* private fields */ }Expand description
Represents an error using Credentials.
The Google Cloud client libraries may experience problems using credentials to create the necessary authentication headers. For example, a temporary failure to retrieve or create access tokens. Note that these failures may happen even after the credentials files are successfully loaded and parsed.
Applications rarely need to create instances of this error type. The exception might be when testing application code, where the application is mocking a client library behavior. Such tests are extremely rare, most applications should only work with the Error type.
Example
use google_cloud_gax::error::CredentialsError;
let mut headers = fetch_headers();
while let Err(e) = &headers {
if e.is_transient() {
headers = fetch_headers();
}
}
fn fetch_headers() -> Result<http::HeaderMap, CredentialsError> {
}Implementations
Sourceimpl CredentialsError
impl CredentialsError
Sourcepub fn is_transient(&self) -> bool
pub fn is_transient(&self) -> bool
Returns true if the error is transient and may succeed in future attempts.
Example
let mut headers = fetch_headers();
while let Err(e) = &headers {
if e.is_transient() {
headers = fetch_headers();
}
}
fn fetch_headers() -> Result<http::HeaderMap, CredentialsError> {
}Trait Implementations
Sourceimpl Clone for CredentialsError
impl Clone for CredentialsError
Sourcefn clone(&self) -> CredentialsError
fn clone(&self) -> CredentialsError
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CredentialsError
impl Debug for CredentialsError
Sourceimpl Display for CredentialsError
impl Display for CredentialsError
Sourceimpl Error for CredentialsError
impl Error for CredentialsError
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
use the Display impl or to_string()
Sourceimpl SubjectTokenProviderError for CredentialsError
impl SubjectTokenProviderError for CredentialsError
Sourcefn is_transient(&self) -> bool
fn is_transient(&self) -> bool