SigningProvider

Trait SigningProvider 

pub trait SigningProvider: Debug {
    // Required methods
    fn client_email(&self) -> impl Future<Output = Result<String>> + Send;
    fn sign(&self, content: &[u8]) -> impl Future<Output = Result<Bytes>> + Send;
}
A trait for types that can sign content.

Required Methods

fn client_email(&self) -> impl Future<Output = Result<String>> + Send

Returns the email address of the authorizer.

It is typically the Google service account client email address from the Google Developers Console in the form of “xxx@developer.gserviceaccount.com”.

fn sign(&self, content: &[u8]) -> impl Future<Output = Result<Bytes>> + Send

Signs the content.

Returns the signature.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors